@@ -65,3 +65,15 @@ sub groups
 }
 
 1;
+
+__END__
+
+=begin LICENSE
+
+Copyright (C) 2010 by Justin Davis
+
+This library is free software; you can redistribute it and/or modify
+it under the same terms as Perl itself, either Perl version 5.10.0 or,
+at your option, any later version of Perl 5 you may have available.
+
+=end LICENSE
